@@ -205,12 +205,12 @@ class KumoTesterScheduler(TesterScheduler):
       manager_computer_partition = self.computer_partition.request(self.software_release_url, 'kumo_manager', 'kumo_manager')
 
       self.computer_partition.request(self.software_release_url, 'kumo_server', 'kumo_server'+str(self.server_count),
-                   partition_parameter_kw={'manager_address':manager_computer_partition.getConnectionParameter('manager_address'),
-                                           'manager_port':manager_computer_partition.getConnectionParameter('manager_port')})
+                   partition_parameter_kw={'manager_address':manager_computer_partition.getConnectionParameter('address'),
+                                           'manager_port':manager_computer_partition.getConnectionParameter('port')})
 
       gateway_computer_partition = self.computer_partition.request(self.software_release_url, 'kumo_gateway', 'kumo_gateway',
-                   partition_parameter_kw={'manager_address':manager_computer_partition.getConnectionParameter('manager_address'),
-                                           'manager_port':manager_computer_partition.getConnectionParameter('manager_port')})
+                   partition_parameter_kw={'manager_address':manager_computer_partition.getConnectionParameter('address'),
+                                           'manager_port':manager_computer_partition.getConnectionParameter('port')})
 
       tester_computer_partition = []
       for i in range(0, 3):
@@ -220,15 +220,10 @@ class KumoTesterScheduler(TesterScheduler):
                                            'gateway_port':gateway_computer_partition.getConnectionParameter('gateway_port'),
                                            'host_address':params['address']}))
         """
-        binary = gateway_computer_partition.getConnectionParameter('memstrike_binary') + \
-                 " -l " + \
-                 gateway_computer_partition.getConnectionParameter('gateway_address').strip("[]") + \
-                 " -p " + \
-                 gateway_computer_partition.getConnectionParameter('gateway_port') + \
-                 " 1000" #" -t 32 1024000"
-        tester_computer_partition.append(self.computer_partition.request(self.software_release_url, 'nosqltester', 'nosqltester'+str(i),
-                   partition_parameter_kw={'host_address':params['address'],
-                                           'binary':binary}))
+        tester_computer_partition.append(self.computer_partition.request(self.software_release_url, 'kumo_tester_easy', 'kumo_tester_easy'+str(i),
+                   partition_parameter_kw={'gateway_address':gateway_computer_partition.getConnectionParameter('address'),
+                                           'gateway_port':gateway_computer_partition.getConnectionParameter('port'),
+                                           'host_address':params['address']}))
       for partition in tester_computer_partition:
         self.tester_urls.append(partition.getConnectionParameter('start_url'))
       self.tester_urls = list(set(self.tester_urls)) # remove duplicates
@@ -241,10 +236,10 @@ class KumoTesterScheduler(TesterScheduler):
   def _add_kumo_server_node(self):
     try:
       partition = self.computer_partition.request(self.software_release_url, 'kumo_server', 'kumo_server'+str(self.server_count),
-                   partition_parameter_kw={'manager_address':self.manager_computer_partition.getConnectionParameter('manager_address'),
-                                           'manager_port':self.manager_computer_partition.getConnectionParameter('manager_port')})
+                   partition_parameter_kw={'manager_address':self.manager_computer_partition.getConnectionParameter('address'),
+                                           'manager_port':self.manager_computer_partition.getConnectionParameter('port')})
       # line made to crash the function call until we call slapgrid
-      partition.getConnectionParameter('server_address')
+      partition.getConnectionParameter('address')
       return True
     except:
       return False
